@@ -36,6 +36,21 @@ import repack
 TB_BASE_URL_RELEASES = "https://ftp.mozilla.org/pub/thunderbird/releases/"
 TB_BASE_URL_CANDIDATES = "https://ftp.mozilla.org/pub/thunderbird/candidates/"
 
+# Some strings we need to exclude within the detection of the current
+# release version.
+RELEASE_STRING_EXCLUSION_LIST = (
+ "esr",
+ "-real",
+ "125.0",
+)
+
+# Also we need to exclude some strings in the current planned version
+# detection.
+PLANNED_STRING_EXCLUSION_LIST = (
+ "124.0",
+ "125.0",
+)
+
 try:
     import colorlog
 
@@ -193,6 +208,8 @@ def get_versions():
                 len(line) == 6
                 and line[3] == "candidates"
                 and line[4].endswith("candidates")
+                # Exclude all "wrong" versions which never will become a ESR version.
+                and not line[4].startswith(PLANNED_STRING_EXCLUSION_LIST)
                 and "b" not in line[4]
             ):
                 # We have now all versions with '-candidates' as suffix which
@@ -231,12 +248,13 @@ def get_versions():
             # Processing all href elements and collect all of them with a numeric version.
             line = elem.split("/")
             if len(line) == 6:
-                # Exclude all non numeric elements.
+                # Exclude all non numeric elements. But also all versions
+                # which never will become a ESR version.
                 if line[4] not in [
                     "custom-updates",
                     "latest",
                     "latest-beta",
-                ] and not line[4].endswith(("esr", "-real")):
+                ] and not line[4].endswith(RELEASE_STRING_EXCLUSION_LIST):
                     tb_upstream_versions.append(line[4])
 
     else:
